@@ -1,5 +1,5 @@
 package FreeBSD::FileSystem;
-$FreeBSD::FileSystem::VERSION = '0.106';
+$FreeBSD::FileSystem::VERSION = '0.107';
 use v5.20;
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ FreeBSD::FileSystem - Class representing a filesystem in a FreeBSD host
 
 =head1 VERSION
 
-version 0.106
+version 0.107
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ Returns the directory where this filesystem is mounted.
 has mountpoint => (
 	is		=> 'ro',
 	isa		=> 'Str',
-	init_arg	=> 'f_mnttoname',
+	init_arg	=> 'f_mntonname',
 );
 
 =item blocksize
@@ -168,5 +168,4 @@ sub pct_avail {
 	100 * $_[0]->avail_blocks / $_[0]->blocks
 }
 
-
 1;
